#!/bin/sh
####################################################################
# set the needed environment variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"
PLOTBAND_COMMAND="/opt/QE61/bin/plotband.x"
####################################################################
# define some QE variables (do not change)
precmd="mpirun -np 4 --map-by core"
name=BTO
struct=cubic
lattice_const=7.47
nK=5
degauss=0.005 # unit: Ry

rm -rf results.band
mkdir results.band
cd results.band

# scf calculation
cat >  $name.$struct.scf.in << EOF1
 &control
    calculation = 'scf' ,
    restart_mode = 'from_scratch' ,
    tstress = .false.
    tprnfor = .true.
    wf_collect=.false. ,
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    verbosity = 'high'
 /
 &system
    ibrav = 6,
    celldm(1)=$lattice_const,
    celldm(3)=1.0236
    nat= 5,
    ntyp= 3,
    ecutwfc = 30,
    occupations='fixed',
    nbnd=22
 /
 &electrons
    mixing_mode = 'plain'
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
Ba    137.34    Ba.pbe-nsp-van.UPF
Ti    47.90     Ti.pbe-sp-van_ak.UPF
O     16.0      O.pbe-rrkjus.UPF

ATOMIC_POSITIONS {crystal}
 Ba    0.00000000000000    0.00000000000000    0.00000000000000
 Ti    0.50000000000000    0.50000000000000    0.50000000000000
  O    0.50000000000000    0.50000000000000    0.00000000000000
  O    0.50000000000000    0.00000000000000    0.50000000000000
  O    0.00000000000000    0.50000000000000    0.50000000000000

K_POINTS automatic
 $nK $nK $nK 0 0 0
EOF1

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in > $name.$struct.scf.out

# Check for scf calc. output
grep -e '!    total energy' $name.$struct.scf.out
grep -e 'End of self-consistent calculation' -A 12 $name.$struct.scf.out
echo -n "Enter the Fermi energy at 0.5*(Emin(unoccu)+Emax(occu)> "
read Ef

# band calculation
cat > $name.$struct.bands.in << EOF2
 &control
    calculation='bands'
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    verbosity='high'
 /
 &system
    ibrav = 6,
    celldm(1)=$lattice_const,
    celldm(3)=1.0236
    nat= 5,
    ntyp= 3,
    ecutwfc = 30,
    ecutrho = 240.0,
    occupations='fixed',
    nbnd=22
 /
 &electrons
    mixing_mode = 'plain'
    conv_thr = 1.0e-8
    mixing_beta = 0.3
 /
&ions
 /
 &cell
 /
ATOMIC_SPECIES
Ba    137.34	Ba.pbe-nsp-van.UPF 
Ti    47.90     Ti.pbe-sp-van_ak.UPF
O     16.0      O.pbe-rrkjus.UPF

ATOMIC_POSITIONS {crystal}
 Ba    0.00000000000000    0.00000000000000    0.00000000000000
 Ti    0.50000000000000    0.50000000000000    0.50000000000000
  O    0.50000000000000    0.50000000000000    0.00000000000000
  O    0.50000000000000    0.00000000000000    0.50000000000000
  O    0.00000000000000    0.50000000000000    0.50000000000000

K_POINTS (tpiba_b)
8
0.0 0.0 0.0  20  # G
0.0 0.5 0.0  20  # X
0.5 0.5 0.0  20  # M
0.0 0.0 0.0  20  # G
0.0 0.0 0.5  20  # Z
0.0 0.5 0.5  20  # R
0.5 0.5 0.5  20  # A
0.0 0.0 0.5  1   # Z
EOF2

$precmd $PW_ROOT/pw.x < $name.$struct.bands.in > $name.$struct.bands.out

# Check the max abd min energies
grep -e "End of band structure calculation" $name.$struct.bands.out -A 6
echo -n "Enter the low end occupied band energy to plot> "
read Emin
echo -n "Enter the high end occupied band energy to plot> "
read Emax

cat > bands.in << EOF3
 &bands
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    filband='$name.$struct.bands'
 /
EOF3

$precmd $PW_ROOT/bands.x < bands.in > bands.out

##### Plotting the band dispersions with plotband.x module #####
Xl=$(echo "$Emin-1" |bc)
#
#  Make files for plotting the band dispersions
cat > plotband.in <<EOF4
$name.$struct.bands
$Emin, $Emax
$name.$struct.bands.xmgr
$name.$struct.bands.eps
$Ef
1.0,$Ef
EOF4
###
$PLOTBAND_COMMAND < plotband.in

##### Combining several xmgr output files into one file #####
cat $name.$struct.bands.xmgr.1.* $name.$struct.bands.xmgr.2 $name.$struct.bands.xmgr.3.* \
$name.$struct.bands.xmgr.4 $name.$struct.bands.xmgr.5.* $name.$struct.bands.xmgr.6 \
$name.$struct.bands.xmgr.7.* $name.$struct.bands.xmgr.8 $name.$struct.bands.xmgr.9.* \
$name.$struct.bands.xmgr.10 $name.$struct.bands.xmgr.11.*>> $name.$struct.bands.xmgr

rm -rf $name.$struct.bands.xmgr.*

cat > plotbands.gnu <<EOF5
#!/usr/bin/gnuplot
reset
# set terminal pngcairo dashed enhanced
set terminal pdfcairo dashed enhanced
# set term wxt enhanced dashed "Arial,16"
# set terminal postscript eps color solid "Helvetica,16"

set output "$name.$struct.bands.pdf"
set zero 1e-18

set xrange [0:4.5]
set yrange [$Emin:$Emax]

set arrow from 0.71, -30 to 0.71, 20 nohead  lw 3
set arrow from 1.21, -30 to 1.21, 20 nohead  lw 3
set arrow from 2.07, -30 to 2.07, 20 nohead  lw 3
set arrow from 3.07, -30 to 3.07, 20 nohead  lw 3
# set arrow from 0., $Ef to 3.8, $Ef nohead lw 1

set ylabel "E (eV)"
unset xtics
set label "{/Symbol G}" at -0.05, $Xl
set label "X" at 0.5, $Xl
set label "M" at 1.0, $Xl
set label "G" at 1.7, $Xl
set label "Z" at 2.2, $Xl
set label "R" at 2.7, $Xl
set label "A" at 3.2, $Xl
set label "Z" at 3.9, $Xl

plot "$name.$struct.bands.xmgr" u 1:2 w l lt 1 lc 1 lw 1
EOF5
