#!/bin/sh
####################################################################
# set the needed environment variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"
####################################################################
# define some QE variables
precmd="mpirun -np 4 --map-by core"
name=BTO
struct=cubic
lattice_const=7.47
nK=15
nKdos=20
degauss=0.01

rm -rf results.dos
mkdir results.dos
cd results.dos

rm -f $name.$struct.scf.out

# scf calculation
cat >  $name.$struct.scf.in << EOF1
 &control
    calculation = 'scf' ,
    restart_mode = 'from_scratch' ,
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    verbosity = 'high'
 /
 &system
    ibrav = 6,
    celldm(1)=$lattice_const,
    celldm(3)=1.0236
    nat= 5,
    ntyp= 3,
    ecutwfc = 30,
    occupations='fixed',
    nbnd=22
 /
 &electrons
    mixing_mode = 'plain'
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
Ba    137.34    Ba.pbe-nsp-van.UPF
Ti    47.90     Ti.pbe-sp-van_ak.UPF
O     16.0      O.pbe-rrkjus.UPF

ATOMIC_POSITIONS {crystal}
 Ba    0.00000000000000    0.00000000000000    0.00000000000000
 Ti    0.50000000000000    0.50000000000000    0.50000000000000
  O    0.50000000000000    0.50000000000000    0.00000000000000
  O    0.50000000000000    0.00000000000000    0.50000000000000
  O    0.00000000000000    0.50000000000000    0.50000000000000

K_POINTS automatic
 $nK $nK $nK 0 0 0
EOF1

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in > $name.$struct.scf.out

# Check for scf calc. output
grep -e '!    total energy' $name.$struct.scf.out
grep -e 'End of self-consistent calculation' -A 12 $name.$struct.scf.out
echo -n "Enter the Fermi energy at 0.5*(Emin(unoccu)+Emax(occu)> "
read Ef

rm -f $name.$struct.nscf.out
# nscf calculation
cat >  $name.$struct.nscf.in << EOF2
 &control
    calculation='nscf'
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    verbosity='high'
 /
 &system
    ibrav = 6,
    celldm(1)=$lattice_const,
    celldm(3)=1.0236
    nat= 5,
    ntyp= 3,
    ecutwfc = 30,
    ecutrho = 240.0,
    occupations='fixed',
    nbnd=22
 /
 &electrons
    mixing_mode = 'plain'
    conv_thr = 1.0e-8
    mixing_beta = 0.3
 /
&ions
 /
 &cell
 /
ATOMIC_SPECIES
Ba    137.34	Ba.pbe-nsp-van.UPF 
Ti    47.90     Ti.pbe-sp-van_ak.UPF
O     16.0      O.pbe-rrkjus.UPF

ATOMIC_POSITIONS {crystal}
 Ba    0.00000000000000    0.00000000000000    0.00000000000000
 Ti    0.50000000000000    0.50000000000000    0.50000000000000
  O    0.50000000000000    0.50000000000000    0.00000000000000
  O    0.50000000000000    0.00000000000000    0.50000000000000
  O    0.00000000000000    0.50000000000000    0.50000000000000

K_POINTS automatic
 $nKdos $nKdos $nKdos 0 0 0
EOF2

$precmd $PW_ROOT/pw.x < $name.$struct.nscf.in > $name.$struct.nscf.out

# Check the max abd min energies
grep -e "End of band structure calculation" $name.$struct.nscf.out -A 6
echo -n "Enter the low end occupied band energy to plot> "
read Emin
echo -n "Enter the high end occupied band energy to plot> "
read Emax

# dos calculation
cat > dos.in << EOF3
&dos
    outdir='$TMP_DIR/' ,
    prefix='$name.$struct' ,
    fildos='$name.$struct.dos',
    ngauss= 0,
    degauss= $degauss,
    Emin=$Emin,
    Emax=$Emax,
    DeltaE=0.1 ! energy grid step (eV)
 /
EOF3

$precmd $PW_ROOT/dos.x < dos.in > dos.out

cat > dos.gnu << EOF4
#!/usr/bin/gnuplot
reset
set terminal pdfcairo dashed enhanced
# set term wxt enhanced dashed "Arial,16"
set for [i=4:6] linetype i dashtype i
set zero 1e-18

set output "$name.$struct.dos.pdf"

set xlabel "E [eV]"
set ylabel "DOS"
set xrange [$Emin:$Emax]
set yrange [0:15]
set arrow from $Ef,0 to $Ef,3 nohead lw 2

plot "$name.$struct.dos" using 1:2 title "DoS" w l lt 1 lc 1 lw 1
EOF4

##### Plotting #####
gnuplot dos.gnu

# pdos calculation
cat >  projwfc.in << EOF5
 &projwfc
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    ngauss=0
    degauss=$degauss
    Emin=$Emin
    Emax=$Emax
    DeltaE=0.1
    filpdos='$name.$struct.pdos'
 /
EOF5

$precmd $PW_ROOT/projwfc.x < projwfc.in > projwfc.out

cat > pdos.gnu << EOF6
#!/usr/bin/gnuplot
reset
set terminal pdfcairo dashed enhanced 
# set term wxt enhanced dashed "Arial,16"
set for [i=4:6] linetype i dashtype i 
set zero 1e-18

set output "$name.$struct.pdos.pdf"

set xlabel "E [eV]"
set ylabel "PDOS"

set xrange [$Emin:$Emax]
set yrange [0:5]
set arrow from $Ef,0 to $Ef,1.2 nohead lw 2

plot "$name.$struct.pdos.pdos_atm#2(Ti)_wfc#3(s)" using 1:2 t "Ti:s" w l lt 1 lc 1 lw 1,\
"$name.$struct.pdos.pdos_atm#2(Ti)_wfc#2(p)" using 1:2 t "Ti:p" w l lt 4 lc 1 lw 1,\
"$name.$struct.pdos.pdos_atm#2(Ti)_wfc#4(d)" using 1:2 t "Ti:d" w l lt 5 lc 2 lw 1,\
"$name.$struct.pdos.pdos_atm#1(Ba)_wfc#4(s)" using 1:2 t "Ba:s" w l lt 1 lc 3 lw 2,\
"$name.$struct.pdos.pdos_atm#1(Ba)_wfc#5(p)" using 1:2 t "Ba:p" w l lt 4 lc 3 lw 2,\
"$name.$struct.pdos.pdos_atm#1(Ba)_wfc#3(d)" using 1:2 t "Ba:d" w l lt 5 lc 4 lw 2,\
"$name.$struct.pdos.pdos_atm#3(O)_wfc#1(s)" using 1:2 t "O:s" w l lt 1 lc 5 lw 2,\
"$name.$struct.pdos.pdos_atm#3(O)_wfc#2(p)" using 1:2 t "O:p" w l lt 4 lc 5 lw 2
EOF6
#### Plotting
gnuplot pdos.gnu
